@@ -26,5 +26,11 @@ module.exports = {
     RetrieveArray: 24,
     SetInstanceField: 25,
     InvokeGenericStaticMethod: 26,
-    InvokeGenericMethod:27
+    InvokeGenericMethod: 27,
+    GetEnumItem: 28,
+    GetEnumName: 29,
+    GetEnumValue: 30,
+    AsRef: 31,
+    AsOut: 32,
+    GetRefValue: 33
 }
\ No newline at end of file
