@@ -3,6 +3,7 @@ use strict;
 use Moose;
 use lib 'lib';
 use warnings FATAL => 'all';
+use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
 
 sub new {
     my $class = shift;
@@ -11,7 +12,7 @@ sub new {
 }
 
 sub process {
-    die Javonet::Core::Handler::Exception->new("Explicit cast is forbidden in dynamically typed languages");
+    die Exception->new("Explicit cast is forbidden in dynamically typed languages");
 }
 
 
