@@ -36,7 +36,7 @@ sub initialize_ {
         $ffi->lib("$current_dir/$perl_native_lib");
         $send_command = $ffi->function('SendCommand' => [ 'uchar[]', 'int' ] => 'int');
         $read_response = $ffi->function('ReadResponse' => [ 'uchar[]', 'int' ] => 'int');
-        $activate = $ffi->function('Activate' => [ 'string', 'string', 'string', 'string', 'string' ] => 'int');
+        $activate = $ffi->function('Activate' => ['string', 'string', 'string', 'string' ] => 'int');
         $get_native_error = $ffi->function('GetNativeError' => [] => 'string')
     }
 }
@@ -62,9 +62,9 @@ sub send_command_ {
 }
 
 sub activate_ {
-    my ($self, $email, $licenceKey, $proxyHost, $proxyUserName, $proxyPassword) = @_;
+    my ($self, $licenceKey, $proxyHost, $proxyUserName, $proxyPassword) = @_;
     initialize_();
-    my $activation_result = $activate->($email, $licenceKey, $proxyHost, $proxyUserName, $proxyPassword);
+    my $activation_result = $activate->($licenceKey, $proxyHost, $proxyUserName, $proxyPassword);
     if ($activation_result < 0) {
         my $error_message = $get_native_error->();
         die "Javonet activation result: $activation_result. $error_message";
